@@ -3,15 +3,22 @@ from .models import Authority, AuthorityKind
 
 
 class AuthorityKindAdmin(admin.ModelAdmin):
-    list_display = ('id', 'name', )
-    search_fields = ('name', )
+    list_display = (
+        "id",
+        "name",
+    )
+    search_fields = ("name",)
 
 
 class AuthorityAdmin(admin.ModelAdmin):
-    list_display = ('id', 'name', 'parent', )
-    search_fields = ('name', )
-    filter_horizontal = ('users',) 
+    list_display = (
+        "id",
+        "name",
+        "parent",
+    )
+    search_fields = ("name",)
+    filter_horizontal = ("users",)
 
 
 admin.site.register(AuthorityKind, AuthorityKindAdmin)
-admin.site.register(Authority, AuthorityAdmin)
\ No newline at end of file
+admin.site.register(Authority, AuthorityAdmin)
