@@ -4,8 +4,10 @@ register = template.Library()
 
 
 @register.simple_tag(takes_context=True)
-def user_authorities(context, ):
+def user_authorities(
+    context,
+):
     try:
         return context.request.user.authorities.all()
     except AttributeError:
-        return []
\ No newline at end of file
+        return []
