@@ -6,31 +6,45 @@ from .forms import AuthorityUsersModelForm
 
 class AuthorityListView(ListView):
     model = Authority
-    context_object_name = 'authorities'
+    context_object_name = "authorities"
 
 
 class AuthorityCreateView(CreateView):
     model = Authority
-    fields = ('name', 'kind', 'is_active', 'parent', )
+    fields = (
+        "name",
+        "kind",
+        "is_active",
+        "parent",
+        "email",
+    )
 
 
 class AuthorityUpdateView(UpdateView):
     model = Authority
-    context_object_name = 'authority'
-    fields = ('name', 'kind', 'is_active', 'parent', )
+    context_object_name = "authority"
+    fields = (
+        "name",
+        "kind",
+        "is_active",
+        "parent",
+        "email",
+    )
 
 
 class AuthorityDetailView(DetailView):
     model = Authority
-    context_object_name = 'authority'
+    context_object_name = "authority"
 
 
-class AuthorityEditUsersView(UpdateView, ):
+class AuthorityEditUsersView(
+    UpdateView,
+):
     model = Authority
     form_class = AuthorityUsersModelForm
     # template_name='authorities/authority_edit_users.html'
-    context_object_name = 'authority'
+    context_object_name = "authority"
 
     def get_form_kwargs(self):
         kwargs = super(AuthorityEditUsersView, self).get_form_kwargs()
-        return kwargs
\ No newline at end of file
+        return kwargs
